## Version 0.11.4

This release includes updates to dependencies and the addition of a new optional dependency, enhancing the flexibility and security of the package.

### New Features

- Updated the hash for the llamabot package to ensure integrity and security of the dependency. (aecfc2) (Eric Ma)
- Added a new optional dependency, llamabot[ui], under the 'rag' extra in pyproject.toml to enhance user interface capabilities. (aecfc2) (Eric Ma)

### Bug Fixes

- No bug fixes in this release.

### Deprecations

- No deprecations in this release.
